
; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.

[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 30

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| Super Motions |--------------------------------------------------------

[Command]
name = "TailsWhirlwind"
command = ~D, DB, B, a+b
time = 20

[Command]
name = "TailsWhirlwind"
command = ~D, DB, B, b+c
time = 20

[Command]
name = "TailsWhirlwind"
command = ~D, DB, B, a+c
time = 20

[Command]
name = "FlyingSlam"
command = ~F, D, DF, x+y
time = 30

[Command]
name = "FlyingSlam"
command = ~F, D, DF, y+z
time = 30

[Command]
name = "FlyingSlam"
command = ~F, D, DF, x+z
time = 30

[Command]
name = "ArmCannonBeam"
command = ~D, DF, F, x+y
time = 20

[Command]
name = "ArmCannonBeam"
command = ~D, DF, F, y+z
time = 20

[Command]
name = "ArmCannonBeam"
command = ~D, DF, F, x+z
time = 20

[Command]
name = "FinalFlight"
command = ~D, DF, F, a+b
time = 20

[Command]
name = "FinalFlight"
command = ~D, DF, F, b+c
time = 20

[Command]
name = "FinalFlight"
command = ~D, DF, F, a+c
time = 20

;-| Special Motions |------------------------------------------------------

[Command]
name = "TailsSpinL"
command = ~D, DB, B, a
time = 20

[Command]
name = "TailsSpinM"
command = ~D, DB, B, b
time = 20

[Command]
name = "TailsSpinH"
command = ~D, DB, B, c
time = 20

[Command]
name = "FistTrap"
command = ~D, DB, B, x
time = 20

[Command]
name = "FistTrap"
command = ~D, DB, B, y
time = 20

[Command]
name = "FistTrap"
command = ~D, DB, B, z
time = 20

[Command]
name = "TailsPounce"
command = ~F, D, DF, x
time = 30

[Command]
name = "TailsPounce"
command = ~F, D, DF, y
time = 30

[Command]
name = "TailsPounce"
command = ~F, D, DF, z
time = 30

[Command]
name = "ArmCannonBlast"
command = ~D, DF, F, x
time = 20

[Command]
name = "ArmCannonBlast"
command = ~D, DF, F, y
time = 20

[Command]
name = "ArmCannonBlast"
command = ~D, DF, F, z
time = 20

;-| Double Tap |-----------------------------------------------------------

[Command]
name = "CrushCounter"
command = /$F, a+b
time = 1

[Command]
name = "CrushCounter"
command = /$F, a+c
time = 1

[Command]
name = "CrushCounter"
command = /$F, b+c
time = 1

[Command]
name = "Pushblock"
command = x+y
time = 1

[Command]
name = "Pushblock"
command = x+z
time = 1

[Command]
name = "Pushblock"
command = y+z
time = 1

[Command]
name = "SnapBack"
command = ~D, DF, F, s
time = 20

[Command]
name = "Assist1"
command = s+a
time = 1

[Command]
name = "Assist1"
command = s+b
time = 1

[Command]
name = "Assist1"
command = s+c
time = 1

[Command]
name = "Assist2"
command = s+x
time = 1

[Command]
name = "Assist2"
command = s+y
time = 1

[Command]
name = "Assist2"
command = s+z
time = 1

[Command] 
name = "SuperJump";Required (do not remove)
command = $D, $U
time = 8

[Command]
name = "IAD_f";Required (do not remove)
command = UF, ~F
time = 10

[Command]
name = "IAD_b";Required (do not remove)
command = UB, ~B
time = 10

[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------

[Command]
name = "throw-f"
command = /F, a+x
time = 1

[Command]
name = "throw-b"
command = /B, a+x
time = 1

[Command]
name = "throw-n"
command = a+x
time = 1

[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,b
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_yb"
command = /F, y+b
time = 1

[Command]
name = "back_yb"
command = /B, y+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "up"
command = ~5UF, /UF
time = 40

[Command]
name = "up"
command = ~5UB, /UB
time = 40

[Command]
name = "up"
command = ~5UB, /UF
time = 40

[Command]
name = "up"
command = ~5UF, /UB
time = 40

[Command]
name = "up"
command = ~5U, /U
time = 40

[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_yb"
command = /y+b
time = 30

[Command]
name = "hold_xa"
command = /x+a
time = 30

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 30

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 30

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;Supers
[State -1]
type = ChangeState
value = 3200
triggerall = command = "FinalFlight"
triggerall = Roundstate = 2 && statetype != A
triggerall = power >= 3000
trigger1 = ctrl
trigger2 = stateno = 200 && movecontact
trigger3 = stateno = 210 && movecontact
trigger4 = stateno = 220 && movecontact
trigger5 = stateno = 230 && movecontact
trigger6 = stateno = 240 && movecontact
trigger7 = stateno = 250 && movecontact
trigger8 = stateno = 400 && movecontact
trigger9 = stateno = 410 && movecontact
trigger10 = stateno = 420 && movecontact
trigger11 = stateno = 430 && movecontact
trigger12 = stateno = 440 && movecontact
trigger13 = stateno = 450 && movecontact
trigger14 = stateno = 1003

[State -1]
type = ChangeState
value = 3100
triggerall = command = "FlyingSlam"
triggerall = Roundstate = 2 && statetype != A
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = stateno = 200 && movecontact
trigger3 = stateno = 210 && movecontact
trigger4 = stateno = 220 && movecontact
trigger5 = stateno = 230 && movecontact
trigger6 = stateno = 240 && movecontact
trigger7 = stateno = 250 && movecontact
trigger8 = stateno = 400 && movecontact
trigger9 = stateno = 410 && movecontact
trigger10 = stateno = 420 && movecontact
trigger11 = stateno = 430 && movecontact
trigger12 = stateno = 440 && movecontact
trigger13 = stateno = 450 && movecontact
trigger14 = stateno = 1003

[State -1]
type = ChangeState
value = 3150
triggerall = command = "ArmCannonBeam"
triggerall = Roundstate = 2 && statetype != A
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = stateno = 200 && movecontact
trigger3 = stateno = 210 && movecontact
trigger4 = stateno = 220 && movecontact
trigger5 = stateno = 230 && movecontact
trigger6 = stateno = 240 && movecontact
trigger7 = stateno = 250 && movecontact
trigger8 = stateno = 400 && movecontact
trigger9 = stateno = 410 && movecontact
trigger10 = stateno = 420 && movecontact
trigger11 = stateno = 430 && movecontact
trigger12 = stateno = 440 && movecontact
trigger13 = stateno = 450 && movecontact
trigger14 = stateno = 1003

[State -1]
type = ChangeState
value = 3000
triggerall = command = "TailsWhirlwind"
triggerall = Roundstate = 2 && statetype != A
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = stateno = 200 && movecontact
trigger3 = stateno = 210 && movecontact
trigger4 = stateno = 220 && movecontact
trigger5 = stateno = 230 && movecontact
trigger6 = stateno = 240 && movecontact
trigger7 = stateno = 250 && movecontact
trigger8 = stateno = 400 && movecontact
trigger9 = stateno = 410 && movecontact
trigger10 = stateno = 420 && movecontact
trigger11 = stateno = 430 && movecontact
trigger12 = stateno = 440 && movecontact
trigger13 = stateno = 450 && movecontact
trigger14 = stateno = 1003

;Specials
[State -1]
type = ChangeState
value = 1200
triggerall = command = "TailsPounce"
triggerall = Roundstate = 2 && statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 && movecontact
trigger3 = stateno = 210 && movecontact
trigger4 = stateno = 220 && movecontact
trigger5 = stateno = 230 && movecontact
trigger6 = stateno = 240 && movecontact
trigger7 = stateno = 250 && movecontact
trigger8 = stateno = 400 && movecontact
trigger9 = stateno = 410 && movecontact
trigger10 = stateno = 420 && movecontact
trigger11 = stateno = 430 && movecontact
trigger12 = stateno = 440 && movecontact
trigger13 = stateno = 450 && movecontact

[State -1]
type = ChangeState
value = 1310
triggerall = command = "ArmCannonBlast"
triggerall = Roundstate = 2 && statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 && movecontact
trigger3 = stateno = 610 && movecontact
trigger4 = stateno = 620 && movecontact
trigger5 = stateno = 630 && movecontact
trigger6 = stateno = 640 && movecontact
trigger7 = stateno = 650 && movecontact

[State -1]
type = ChangeState
value = 1300
triggerall = command = "ArmCannonBlast"
triggerall = Roundstate = 2 && statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 && movecontact
trigger3 = stateno = 210 && movecontact
trigger4 = stateno = 220 && movecontact
trigger5 = stateno = 230 && movecontact
trigger6 = stateno = 240 && movecontact
trigger7 = stateno = 250 && movecontact
trigger8 = stateno = 400 && movecontact
trigger9 = stateno = 410 && movecontact
trigger10 = stateno = 420 && movecontact
trigger11 = stateno = 430 && movecontact
trigger12 = stateno = 440 && movecontact
trigger13 = stateno = 450 && movecontact

[State -1]
type = ChangeState
value = 1100
triggerall = command = "FistTrap"
triggerall = Roundstate = 2 && statetype != A
triggerall = NumHelper(1100) < 1
trigger1 = ctrl
trigger2 = stateno = 200 && movecontact
trigger3 = stateno = 210 && movecontact
trigger4 = stateno = 220 && movecontact
trigger5 = stateno = 230 && movecontact
trigger6 = stateno = 240 && movecontact
trigger7 = stateno = 250 && movecontact
trigger8 = stateno = 400 && movecontact
trigger9 = stateno = 410 && movecontact
trigger10 = stateno = 420 && movecontact
trigger11 = stateno = 430 && movecontact
trigger12 = stateno = 440 && movecontact
trigger13 = stateno = 450 && movecontact

[State -1]
type = ChangeState
value = 1000
triggerall = command = "TailsSpinL"
triggerall = Roundstate = 2 && statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 && movecontact
trigger3 = stateno = 210 && movecontact
trigger4 = stateno = 220 && movecontact
trigger5 = stateno = 230 && movecontact
trigger6 = stateno = 240 && movecontact
trigger7 = stateno = 250 && movecontact
trigger8 = stateno = 400 && movecontact
trigger9 = stateno = 410 && movecontact
trigger10 = stateno = 420 && movecontact
trigger11 = stateno = 430 && movecontact
trigger12 = stateno = 440 && movecontact
trigger13 = stateno = 450 && movecontact

[State -1]
type = ChangeState
value = 1001
triggerall = command = "TailsSpinM"
triggerall = Roundstate = 2 && statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 && movecontact
trigger3 = stateno = 210 && movecontact
trigger4 = stateno = 220 && movecontact
trigger5 = stateno = 230 && movecontact
trigger6 = stateno = 240 && movecontact
trigger7 = stateno = 250 && movecontact
trigger8 = stateno = 400 && movecontact
trigger9 = stateno = 410 && movecontact
trigger10 = stateno = 420 && movecontact
trigger11 = stateno = 430 && movecontact
trigger12 = stateno = 440 && movecontact
trigger13 = stateno = 450 && movecontact

[State -1]
type = ChangeState
value = 1002
triggerall = command = "TailsSpinH"
triggerall = Roundstate = 2 && statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 && movecontact
trigger3 = stateno = 210 && movecontact
trigger4 = stateno = 220 && movecontact
trigger5 = stateno = 230 && movecontact
trigger6 = stateno = 240 && movecontact
trigger7 = stateno = 250 && movecontact
trigger8 = stateno = 400 && movecontact
trigger9 = stateno = 410 && movecontact
trigger10 = stateno = 420 && movecontact
trigger11 = stateno = 430 && movecontact
trigger12 = stateno = 440 && movecontact
trigger13 = stateno = 450 && movecontact

[State -1]
type = ChangeState
value = 1010
triggerall = command = "TailsSpinL" || command = "TailsSpinM" || command = "TailsSpinH"
triggerall = Roundstate = 2 && statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 && movecontact
trigger3 = stateno = 610 && movecontact
trigger4 = stateno = 620 && movecontact
trigger5 = stateno = 630 && movecontact
trigger6 = stateno = 640 && movecontact
trigger7 = stateno = 650 && movecontact

;Throws
[State -1]
type = ChangeState
value = 830
triggerall = command = "throw-b"
trigger1 = statetype = S && ctrl

[State -1]
type = ChangeState
value = 800
triggerall = command = "throw-f" || command = "throw-n"
trigger1 = statetype = S && ctrl

;Aerials
[State -1]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A && ctrl
trigger2 = stateno = 600 && movecontact

[State -1]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A && ctrl
trigger2 = stateno = 600 && movecontact
trigger3 = stateno = 630 && movecontact
trigger4 = stateno = 610 && movecontact

[State -1]
type = ChangeState
value = 650
triggerall = command = "c"
trigger1 = statetype = A && ctrl
trigger2 = stateno = 610 && movecontact
trigger3 = stateno = 640 && movecontact
trigger4 = stateno = 620 && movecontact

[State -1]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A && ctrl

[State -1]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A && ctrl
trigger2 = stateno = 600 && movecontact
trigger3 = stateno = 630 && movecontact

[State -1]
type = ChangeState
value = 620
triggerall = command = "z"
trigger1 = statetype = A && ctrl
trigger2 = stateno = 610 && movecontact
trigger3 = stateno = 640 && movecontact

;Crouching Normals
[State -1]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = stateno = 400 && movecontact

[State -1]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = stateno = 400 && movecontact
trigger3 = stateno = 430 && movecontact
trigger4 = stateno = 410 && movecontact
trigger5 = stateno = 200 && movecontact
trigger6 = stateno = 230 && movecontact
trigger7 = stateno = 210 && movecontact

[State -1]
type = ChangeState
value = 450
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = stateno = 410 && movecontact
trigger3 = stateno = 440 && movecontact
trigger4 = stateno = 420 && movecontact
trigger5 = stateno = 210 && movecontact
trigger6 = stateno = 240 && movecontact

[State -1]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C && ctrl

[State -1]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = stateno = 400 && movecontact
trigger3 = stateno = 430 && movecontact
trigger4 = stateno = 200 && movecontact
trigger5 = stateno = 230 && movecontact

[State -1]
type = ChangeState
value = 420
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = stateno = 410 && movecontact
trigger3 = stateno = 440 && movecontact
trigger5 = stateno = 210 && movecontact
trigger6 = stateno = 240 && movecontact

;Normals
[State -1]
type = ChangeState
value = 230
triggerall = command = "a"
trigger1 = statetype = S && ctrl
trigger2 = stateno = 100
trigger3 = stateno = 200 && movecontact

[State -1]
type = ChangeState
value = 240
triggerall = command = "b"
trigger1 = statetype = S && ctrl
trigger2 = stateno = 200 && movecontact
trigger3 = stateno = 230 && movecontact
trigger4 = stateno = 210 && movecontact
trigger5 = stateno = 400 && movecontact
trigger6 = stateno = 430 && movecontact
trigger7 = stateno = 410 && movecontact

[State -1]
type = ChangeState
value = 250
triggerall = command = "c"
trigger1 = statetype = S && ctrl
trigger2 = stateno = 210 && movecontact
trigger3 = stateno = 240 && movecontact
trigger4 = stateno = 410 && movecontact
trigger5 = stateno = 440 && movecontact

[State -1]
type = ChangeState
value = 200
triggerall = command = "x"
trigger1 = statetype = S && ctrl
trigger2 = stateno = 100

[State -1]
type = ChangeState
value = 210
triggerall = command = "y"
trigger1 = statetype = S && ctrl
trigger2 = stateno = 200 && movecontact
trigger3 = stateno = 230 && movecontact
trigger4 = stateno = 400 && movecontact
trigger5 = stateno = 430 && movecontact

[State -1]
type = ChangeState
value = 220
triggerall = command = "z"
trigger1 = statetype = S && ctrl
trigger2 = stateno = 210 && movecontact
trigger3 = stateno = 240 && movecontact
trigger4 = stateno = 410 && movecontact
trigger5 = stateno = 440 && movecontact

;Double Jump Cancel
[State -1, Double Jump Cancel]
type = ChangeState
value = 45
triggerall = Roundstate = 2 && statetype = A
triggerall = command = "holdup" && var(2) = 0
trigger1 = stateno = 600 && movecontact
trigger2 = stateno = 610 && movecontact
trigger3 = stateno = 620 && movecontact
trigger4 = stateno = 630 && movecontact
trigger5 = stateno = 640 && movecontact
trigger6 = stateno = 650 && movecontact

;Crush Counter
[State -1]
type = ChangeState
value = 900
triggerall = command = "CrushCounter"
triggerall = power >= 500
trigger1 = stateno = 150
trigger2 = stateno = 151
trigger3 = stateno = 152
trigger4 = stateno = 153

;Super Jump
[State -1, Super Jump]
type = ChangeState
value = 46
trigger1 = stateno = 11 && command = "SuperJump"
trigger2 = stateno = 40 && command = "SuperJump"
trigger3 = stateno = 450 && movecontact && command = "holdup"
trigger4 = var(1) = 1 && command = "holdup" && statetype != A && ctrl

;Air Dash Back
[State -1, Air Dash Back]
type = ChangeState
value = 115
triggerall = command = "BB" ||  Command = "IAD_b"
triggerall = Var(10) < 1
trigger1 = statetype = A && ctrl

;Air Dash Fwd
[State -1, Air Dash Fwd]
type = ChangeState
value = 110
triggerall = command = "FF" || Command = "IAD_f"
triggerall = Var(10) < 1
trigger1 = statetype = A && ctrl

;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = command = "FF"
trigger1 = statetype = S && ctrl

;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = command = "BB"
trigger1 = statetype = S && ctrl

;Snap Back
[State -1]
type = ChangeState
value = 950
triggerall = command = "SnapBack"
triggerall = Roundstate = 2 && statetype != A
trigger1 = ctrl
triggerall = power >= 500
trigger2 = stateno = 200 && movecontact
trigger3 = stateno = 210 && movecontact
trigger4 = stateno = 220 && movecontact
trigger5 = stateno = 230 && movecontact
trigger6 = stateno = 240 && movecontact
trigger7 = stateno = 250 && movecontact
trigger9 = stateno = 400 && movecontact
trigger10 = stateno = 410 && movecontact
trigger11 = stateno = 420 && movecontact
trigger12 = stateno = 430 && movecontact
trigger13 = stateno = 440 && movecontact
trigger14 = stateno = 450 && movecontact

;Taunt
[State -1, Taunt]
type = changestate
value = 195
triggerall = command = "s"
trigger1 = statetype = S && !NumPartner && ctrl

;Assist
[State -1, Partner Assist]
type = VarSet
sysvar(4) = 10
triggerall = sysvar(4) = 1 || sysvar(4) = 15
triggerall = NumPartner
triggerall = RoundState = 2
triggerall = Partner, StateNo = [1251112,1251114]
triggerall = Partner, Time >= 60 && Time > 0
triggerall = teammode = Simul
triggerall = hitdefattr != SCA, HA, HP, HT
triggerAll = StateNo != [130,140]
triggerall = !(StateNo = [5000,5700])
triggerall = Partner,StateNo != [5000,5700]
;triggerall = !AILevel
trigger1 = command="x"||command="y"||command="z"||command="a"||command="b"||command="c"
trigger1 = command = "s"
trigger2 = ctrl ;&& Movetype = A
;trigger2 = Random < (((2 * ifelse(MoveContact, ifelse(MoveHit, 2, 3),1)) + (UniqHitCount * 2))
trigger3 = Random < 300 && AILevel
ignorehitpause = 1

;Tag
[State -1, TagIn]
type = ChangeState
value = 1251110
triggerall = sysvar(4) = 1 || sysvar(4) = 15
triggerall = NumPartner && NumEnemy
triggerall = RoundState = 2 
triggerall = Partner, life > 0
triggerall = Partner, StateNo = [1251112,1251114]
triggerall = Partner, Time >= 40	
triggerall = (MoveType != A && StateType != A) && (Ctrl = 1)
trigger1 = command = "s"
;trigger2 = Random < (ifelse((LifeMax/Life > 120), 120, LifeMax/Life)+((EnemyNear,statetype=L)*25))
trigger2 = Life < Partner, Life && Partner, Time > 1 * TicksPerSecond
;trigger3 = Life < Partner, Life && Partner, Time > 1 * TicksPerSecond && Life < LifeMax * (LifeMax*0.55)
trigger3 = Random < ((ifelse(LifeMax/Life > 10, 10, LifeMax/Life) + (10+ifelse((EnemyNear, StateNo > 5000),25,1))) * ifelse((Life < Partner, Life), 1.45, 0.5)) && AILevel
trigger3 = Partner, Time > 1 * TicksPerSecond
trigger3= EnemyNear, statetype = L || p2bodydist x > 250 && EnemyNear, movetype != A
trigger4 = Life < 150 && Life < Partner, Life && AILevel
;trigger4 = EnemyNear, statetype = L || p2bodydist x > 200 && EnemyNear, movetype != A
trigger4 = Random < (125) && AILevel

;[State -1, C_6]
;type = CtrlSet
;value = 1
;triggerall = RoundState = 2 && NumPartner
;triggerall = NumTarget && Target, StateNo != [200,4999]
;triggerall = StateNo != 1251106 && !Ctrl
;triggerall = (Partner, StateNo != [1251128,1251129]) && (Partner, PrevStateNo != [1251128,1251129])
;trigger1 = command="x"||command="y"||command="z"||command="a"||command="b"||command="c"
;trigger1 = sysvar(4) = 7
;trigger1 = Movetype = A
;trigger1 = MoveContact
;trigger1 = hitdefattr = SCA, NA, SA
;trigger1 = StateNo != PrevStateNo
;trigger1 = Time > 3
;trigger2 = PrevStateNo = 1251106
;ignorehitpause = 0

;AI
[State -1, Super Jump]
type = ChangeState
value = 46
triggerall = AILevel > 4
triggerall = Enemy, NumProj > 0
triggerall = Roundstate = 2
trigger1 = statetype !=A
trigger1 = ctrl

[State -1, Super Jump]
type = ChangeState
value = 46
triggerall = AILevel > 2
triggerall = Roundstate = 2
trigger1 = stateno = 450 && movehit
trigger2 = var(1) = 1 && command = "holdup" && statetype != A && ctrl

[State -1]
type = ChangeState
value = 250
triggerall = P2Bodydist X <= 14
triggerall = AILevel > 2
triggerall = Roundstate = 2
trigger1 = stateno = 210 && movecontact && random >= 500 || stateno = 240 && movecontact && random >= 500

[State -1]
type = ChangeState
value = 450
triggerall = P2Bodydist X <= 14
triggerall = AILevel > 2
triggerall = Roundstate = 2
trigger1 = stateno = 210 && movecontact && random < 500 || stateno = 440 && movecontact && random < 500

[State -1]
type = ChangeState
value = 440
triggerall = P2Bodydist X <= 14
triggerall = AILevel > 2
triggerall = Roundstate = 2
trigger1 = stateno = 200 && movecontact && random >= 500 || stateno = 230 && movecontact && random >= 500

[State -1]
type = ChangeState
value = 210
triggerall = P2Bodydist X <= 14
triggerall = AILevel > 2
triggerall = Roundstate = 2
trigger1 = stateno = 200 && movecontact && random < 500 || stateno = 230 && movecontact && random < 500

[State -1]
type = ChangeState
value = 230
triggerall = P2Bodydist X <= 14
triggerall = random = [200, 399]
triggerall = AILevel > 2
triggerall = Roundstate = 2
trigger1 = statetype !=A
trigger1 = ctrl

[State -1]
type = ChangeState
value = 200
triggerall = P2Bodydist X <= 14
triggerall = random = [0, 199]
triggerall = AILevel > 2
triggerall = Roundstate = 2
trigger1 = statetype !=A
trigger1 = ctrl

[State -1]
type = ChangeState
value = 1002
triggerall = P2Bodydist X <= 14
triggerall = random = [400, 599]
triggerall = AILevel > 2
triggerall = Roundstate = 2
trigger1 = statetype !=A
trigger1 = ctrl

[State -1]
type = ChangeState
value = 800
triggerall = P2Bodydist X <= 14
triggerall = random>=600
triggerall = AILevel > 2
triggerall = power < 1000
triggerall = Roundstate = 2
trigger1 = statetype !=A
trigger1 = ctrl

[State -1]
type = ChangeState
value = 3000
triggerall = P2Bodydist X <= 14
triggerall = random>=600
triggerall = AILevel > 3
triggerall = power >= 1000
triggerall = Roundstate = 2
trigger1 = statetype !=A
trigger1 = ctrl

[State -1]
type = ChangeState
value = 1100
triggerall = P2Bodydist X >= 130
triggerall = random>=500
triggerall = AILevel > 3
triggerall = Roundstate = 2
triggerall = NumHelper(1100) < 1
trigger1 = statetype !=A
trigger1 = ctrl

[State -1, Super Jump]
type = ChangeState
value = 46
triggerall = P2Bodydist X >= 130
triggerall = AILevel > 3
triggerall = Roundstate = 2
triggerall = random < 500
trigger1 = statetype !=A
trigger1 = ctrl

[State -1]
type = ChangeState
value = 1010
triggerall = P2Bodydist Y > 74
triggerall = random <= 600
triggerall = AILevel > 6
triggerall = Roundstate = 2
trigger1 = statetype = A
trigger1 = ctrl

[State -1]
type = ChangeState
value = 1200
triggerall = P2Bodydist X = [15,30]
triggerall = P2Bodydist Y = [20,75]
triggerall = AILevel > 5
triggerall = power < 1000
triggerall = Roundstate = 2
trigger1 = statetype !=A
trigger1 = ctrl

[State -1]
type = ChangeState
value = 3100
triggerall = P2Bodydist X = [15,30]
triggerall = P2Bodydist Y = [20,75]
triggerall = AILevel > 5
triggerall = power >= 1000
triggerall = Roundstate = 2
trigger1 = statetype !=A
trigger1 = ctrl
